@@ -1,6 +1,5 @@
-from django.conf.urls.defaults import *
+from django.conf.urls import patterns, include, url
 from models import Event
-from django.views.generic.dates import DateDetailView
 
 urlpatterns = patterns('',
     url(r'^$', 'simple_events.views.events', name='events'),
